==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ProvideCalculatorEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescription } from "./ProvideCalculatorEventArgsDescription";
/**
 * @hidden
 */
export let ProvideCalculatorEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ProvideCalculatorEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ProvideCalculatorEventArgsDescriptionMetadata.a == null) {
                ProvideCalculatorEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ProvideCalculatorEventArgsDescriptionMetadata.c(ProvideCalculatorEventArgsDescriptionMetadata.a);
            }
            if (a.k(ProvideCalculatorEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ProvideCalculatorEventArgsDescriptionMetadata.b(a);
            a.ad("ProvideCalculatorEventArgs", () => new ProvideCalculatorEventArgsDescription());
            a.ac("ProvideCalculatorEventArgs", ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
    }
    ProvideCalculatorEventArgsDescriptionMetadata.$t = markType(ProvideCalculatorEventArgsDescriptionMetadata, 'ProvideCalculatorEventArgsDescriptionMetadata');
    ProvideCalculatorEventArgsDescriptionMetadata.a = null;
    return ProvideCalculatorEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ProvideCalculatorEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescription } from "./ProvideCalculatorEventArgsDescription";
/**
 * @hidden
 */
export let ProvideCalculatorEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ProvideCalculatorEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ProvideCalculatorEventArgsDescriptionMetadata.a == null) {
                ProvideCalculatorEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ProvideCalculatorEventArgsDescriptionMetadata.c(ProvideCalculatorEventArgsDescriptionMetadata.a);
            }
            if (a.k(ProvideCalculatorEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ProvideCalculatorEventArgsDescriptionMetadata.b(a);
            a.ae("ProvideCalculatorEventArgs", () => new ProvideCalculatorEventArgsDescription());
            a.ad("ProvideCalculatorEventArgs", ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
    }
    ProvideCalculatorEventArgsDescriptionMetadata.$t = markType(ProvideCalculatorEventArgsDescriptionMetadata, 'ProvideCalculatorEventArgsDescriptionMetadata');
    ProvideCalculatorEventArgsDescriptionMetadata.a = null;
    return ProvideCalculatorEventArgsDescriptionMetadata;
})();
